svn commit: r189292 - in head/lib/libc/db: btree recno

Xin LI delphij at FreeBSD.org
Mon Mar 2 18:16:13 PST 2009


Author: delphij
Date: Tue Mar  3 02:16:12 2009
New Revision: 189292
URL: http://svn.freebsd.org/changeset/base/189292

Log:
  Rename variable 'index' to 'idx' to avoid name collision with index(3),
  this commit does not affect any object code.
  
  Obtained from:	OpenBSD
  Verified with:	md5(1)

Modified:
  head/lib/libc/db/btree/bt_delete.c
  head/lib/libc/db/btree/bt_put.c
  head/lib/libc/db/btree/bt_search.c
  head/lib/libc/db/btree/bt_seq.c
  head/lib/libc/db/recno/rec_delete.c
  head/lib/libc/db/recno/rec_put.c
  head/lib/libc/db/recno/rec_search.c

Modified: head/lib/libc/db/btree/bt_delete.c
==============================================================================
--- head/lib/libc/db/btree/bt_put.c	Mon Mar  2 23:47:18 2009	(r189291)
+++ head/lib/libc/db/btree/bt_put.c	Tue Mar  3 02:16:12 2009	(r189292)
@@ -68,7 +68,7 @@ __bt_put(const DB *dbp, DBT *key, const 
 	DBT tkey, tdata;
 	EPG *e;
 	PAGE *h;
-	indx_t index, nxtindex;
+	indx_t idx, nxtindex;
 	pgno_t pg;
 	u_int32_t nbytes, tmp;
 	int dflags, exact, status;
@@ -149,7 +149,7 @@ storekey:		if (__ovfl_put(t, key, &pg) =
 	if (flags == R_CURSOR) {
 		if ((h = mpool_get(t->bt_mp, t->bt_cursor.pg.pgno, 0)) == NULL)
 			return (RET_ERROR);
-		index = t->bt_cursor.pg.index;
+		idx = t->bt_cursor.pg.index;
 		goto delete;
 	}
 
@@ -161,7 +161,7 @@ storekey:		if (__ovfl_put(t, key, &pg) =
 		if ((e = __bt_search(t, key, &exact)) == NULL)
 			return (RET_ERROR);
 	h = e->page;
-	index = e->index;
+	idx = e->index;
 
 	/*
 	 * Add the key/data pair to the tree.  If an identical key is already
@@ -183,7 +183,7 @@ storekey:		if (__ovfl_put(t, key, &pg) =
 		 * Note, the delete may empty the page, so we need to put a
 		 * new entry into the page immediately.
 		 */
-delete:		if (__bt_dleaf(t, key, h, index) == RET_ERROR) {
+delete:		if (__bt_dleaf(t, key, h, idx) == RET_ERROR) {
 			mpool_put(t->bt_mp, h, 0);
 			return (RET_ERROR);
 		}
@@ -199,35 +199,35 @@ delete:		if (__bt_dleaf(t, key, h, index
 	nbytes = NBLEAFDBT(key->size, data->size);
 	if (h->upper - h->lower < nbytes + sizeof(indx_t)) {
 		if ((status = __bt_split(t, h, key,
-		    data, dflags, nbytes, index)) != RET_SUCCESS)
+		    data, dflags, nbytes, idx)) != RET_SUCCESS)
 			return (status);
 		goto success;
 	}
 
-	if (index < (nxtindex = NEXTINDEX(h)))
-		memmove(h->linp + index + 1, h->linp + index,
-		    (nxtindex - index) * sizeof(indx_t));
+	if (idx < (nxtindex = NEXTINDEX(h)))
+		memmove(h->linp + idx + 1, h->linp + idx,
+		    (nxtindex - idx) * sizeof(indx_t));
 	h->lower += sizeof(indx_t);
 
-	h->linp[index] = h->upper -= nbytes;
+	h->linp[idx] = h->upper -= nbytes;
 	dest = (char *)h + h->upper;
 	WR_BLEAF(dest, key, data, dflags);
 
 	/* If the cursor is on this page, adjust it as necessary. */
 	if (F_ISSET(&t->bt_cursor, CURS_INIT) &&
 	    !F_ISSET(&t->bt_cursor, CURS_ACQUIRE) &&
-	    t->bt_cursor.pg.pgno == h->pgno && t->bt_cursor.pg.index >= index)
+	    t->bt_cursor.pg.pgno == h->pgno && t->bt_cursor.pg.index >= idx)
 		++t->bt_cursor.pg.index;
 
 	if (t->bt_order == NOT) {
 		if (h->nextpg == P_INVALID) {
-			if (index == NEXTINDEX(h) - 1) {
+			if (idx == NEXTINDEX(h) - 1) {
 				t->bt_order = FORWARD;
-				t->bt_last.index = index;
+				t->bt_last.index = idx;
 				t->bt_last.pgno = h->pgno;
 			}
 		} else if (h->prevpg == P_INVALID) {
-			if (index == 0) {
+			if (idx == 0) {
 				t->bt_order = BACK;
 				t->bt_last.index = 0;
 				t->bt_last.pgno = h->pgno;

Modified: head/lib/libc/db/btree/bt_search.c
==============================================================================
--- head/lib/libc/db/btree/bt_search.c	Mon Mar  2 23:47:18 2009	(r189291)
+++ head/lib/libc/db/btree/bt_search.c	Tue Mar  3 02:16:12 2009	(r189292)
@@ -64,7 +64,7 @@ EPG *
 __bt_search(BTREE *t, const DBT *key, int *exactp)
 {
 	PAGE *h;
-	indx_t base, index, lim;
+	indx_t base, idx, lim;
 	pgno_t pg;
 	int cmp;
 
@@ -76,7 +76,7 @@ __bt_search(BTREE *t, const DBT *key, in
 		/* Do a binary search on the current page. */
 		t->bt_cur.page = h;
 		for (base = 0, lim = NEXTINDEX(h); lim; lim >>= 1) {
-			t->bt_cur.index = index = base + (lim >> 1);
+			t->bt_cur.index = idx = base + (lim >> 1);
 			if ((cmp = __bt_cmp(t, key, &t->bt_cur)) == 0) {
 				if (h->flags & P_BLEAF) {
 					*exactp = 1;
@@ -85,7 +85,7 @@ __bt_search(BTREE *t, const DBT *key, in
 				goto next;
 			}
 			if (cmp > 0) {
-				base = index + 1;
+				base = idx + 1;
 				--lim;
 			}
 		}
@@ -121,10 +121,10 @@ __bt_search(BTREE *t, const DBT *key, in
 		 * be a parent page for the key.  If a split later occurs, the
 		 * inserted page will be to the right of the saved page.
 		 */
-		index = base ? base - 1 : base;
+		idx = base ? base - 1 : base;
 
-next:		BT_PUSH(t, h->pgno, index);
-		pg = GETBINTERNAL(h, index)->pgno;
+next:		BT_PUSH(t, h->pgno, idx);
+		pg = GETBINTERNAL(h, idx)->pgno;
 		mpool_put(t->bt_mp, h, 0);
 	}
 }

Modified: head/lib/libc/db/btree/bt_seq.c
==============================================================================
--- head/lib/libc/db/recno/rec_put.c	Mon Mar  2 23:47:18 2009	(r189291)
+++ head/lib/libc/db/recno/rec_put.c	Tue Mar  3 02:16:12 2009	(r189292)
@@ -191,7 +191,7 @@ __rec_iput(BTREE *t, recno_t nrec, const
 	DBT tdata;
 	EPG *e;
 	PAGE *h;
-	indx_t index, nxtindex;
+	indx_t idx, nxtindex;
 	pgno_t pg;
 	u_int32_t nbytes;
 	int dflags, status;
@@ -222,7 +222,7 @@ __rec_iput(BTREE *t, recno_t nrec, const
 		return (RET_ERROR);
 
 	h = e->page;
-	index = e->index;
+	idx = e->index;
 
 	/*
 	 * Add the specified key/data pair to the tree.  The R_IAFTER and
@@ -232,13 +232,13 @@ __rec_iput(BTREE *t, recno_t nrec, const
 	 */
 	switch (flags) {
 	case R_IAFTER:
-		++index;
+		++idx;
 		break;
 	case R_IBEFORE:
 		break;
 	default:
 		if (nrec < t->bt_nrecs &&
-		    __rec_dleaf(t, h, index) == RET_ERROR) {
+		    __rec_dleaf(t, h, idx) == RET_ERROR) {
 			mpool_put(t->bt_mp, h, 0);
 			return (RET_ERROR);
 		}
@@ -252,18 +252,18 @@ __rec_iput(BTREE *t, recno_t nrec, const
 	 */
 	nbytes = NRLEAFDBT(data->size);
 	if (h->upper - h->lower < nbytes + sizeof(indx_t)) {
-		status = __bt_split(t, h, NULL, data, dflags, nbytes, index);
+		status = __bt_split(t, h, NULL, data, dflags, nbytes, idx);
 		if (status == RET_SUCCESS)
 			++t->bt_nrecs;
 		return (status);
 	}
 
-	if (index < (nxtindex = NEXTINDEX(h)))
-		memmove(h->linp + index + 1, h->linp + index,
-		    (nxtindex - index) * sizeof(indx_t));
+	if (idx < (nxtindex = NEXTINDEX(h)))
+		memmove(h->linp + idx + 1, h->linp + idx,
+		    (nxtindex - idx) * sizeof(indx_t));
 	h->lower += sizeof(indx_t);
 
-	h->linp[index] = h->upper -= nbytes;
+	h->linp[idx] = h->upper -= nbytes;
 	dest = (char *)h + h->upper;
 	WR_RLEAF(dest, data, dflags);
 

Modified: head/lib/libc/db/recno/rec_search.c
==============================================================================
--- head/lib/libc/db/recno/rec_search.c	Mon Mar  2 23:47:18 2009	(r189291)
+++ head/lib/libc/db/recno/rec_search.c	Tue Mar  3 02:16:12 2009	(r189292)
@@ -61,7 +61,7 @@ __FBSDID("$FreeBSD$");
 EPG *
 __rec_search(BTREE *t, recno_t recno, enum SRCHOP op)
 {
-	indx_t index;
+	indx_t idx;
 	PAGE *h;
 	EPGNO *parent;
 	RINTERNAL *r;
@@ -79,23 +79,23 @@ __rec_search(BTREE *t, recno_t recno, en
 			t->bt_cur.index = recno - total;
 			return (&t->bt_cur);
 		}
-		for (index = 0, top = NEXTINDEX(h);;) {
-			r = GETRINTERNAL(h, index);
-			if (++index == top || total + r->nrecs > recno)
+		for (idx = 0, top = NEXTINDEX(h);;) {
+			r = GETRINTERNAL(h, idx);
+			if (++idx == top || total + r->nrecs > recno)
 				break;
 			total += r->nrecs;
 		}
 
-		BT_PUSH(t, pg, index - 1);
+		BT_PUSH(t, pg, idx - 1);
 		
 		pg = r->pgno;
 		switch (op) {
 		case SDELETE:
-			--GETRINTERNAL(h, (index - 1))->nrecs;
+			--GETRINTERNAL(h, (idx - 1))->nrecs;
 			mpool_put(t->bt_mp, h, MPOOL_DIRTY);
 			break;
 		case SINSERT:
-			++GETRINTERNAL(h, (index - 1))->nrecs;
+			++GETRINTERNAL(h, (idx - 1))->nrecs;
 			mpool_put(t->bt_mp, h, MPOOL_DIRTY);
 			break;
 		case SEARCH:


More information about the svn-src-all mailing list
--- head/lib/libc/db/btree/bt_delete.c	Mon Mar  2 23:47:18 2009	(r189291)
+++ head/lib/libc/db/btree/bt_delete.c	Tue Mar  3 02:16:12 2009	(r189292)
@@ -142,7 +142,7 @@ __bt_stkacq(BTREE *t, PAGE **hp, CURSOR 
 	EPG *e;
 	EPGNO *parent;
 	PAGE *h;
-	indx_t index;
+	indx_t idx;
 	pgno_t pgno;
 	recno_t nextpg, prevpg;
 	int exact, level;
@@ -180,8 +180,8 @@ __bt_stkacq(BTREE *t, PAGE **hp, CURSOR 
 
 			/* Move to the next index. */
 			if (parent->index != NEXTINDEX(h) - 1) {
-				index = parent->index + 1;
-				BT_PUSH(t, h->pgno, index);
+				idx = parent->index + 1;
+				BT_PUSH(t, h->pgno, idx);
 				break;
 			}
 			mpool_put(t->bt_mp, h, 0);
@@ -190,7 +190,7 @@ __bt_stkacq(BTREE *t, PAGE **hp, CURSOR 
 		/* Restore the stack. */
 		while (level--) {
 			/* Push the next level down onto the stack. */
-			bi = GETBINTERNAL(h, index);
+			bi = GETBINTERNAL(h, idx);
 			pgno = bi->pgno;
 			BT_PUSH(t, pgno, 0);
 
@@ -200,7 +200,7 @@ __bt_stkacq(BTREE *t, PAGE **hp, CURSOR 
 			/* Get the next level down. */
 			if ((h = mpool_get(t->bt_mp, pgno, 0)) == NULL)
 				return (1);
-			index = 0;
+			idx = 0;
 		}
 		mpool_put(t->bt_mp, h, 0);
 		if ((h = mpool_get(t->bt_mp, nextpg, 0)) == NULL)
@@ -235,8 +235,8 @@ __bt_stkacq(BTREE *t, PAGE **hp, CURSOR 
 
 			/* Move to the next index. */
 			if (parent->index != 0) {
-				index = parent->index - 1;
-				BT_PUSH(t, h->pgno, index);
+				idx = parent->index - 1;
+				BT_PUSH(t, h->pgno, idx);
 				break;
 			}
 			mpool_put(t->bt_mp, h, 0);
@@ -245,7 +245,7 @@ __bt_stkacq(BTREE *t, PAGE **hp, CURSOR 
 		/* Restore the stack. */
 		while (level--) {
 			/* Push the next level down onto the stack. */
-			bi = GETBINTERNAL(h, index);
+			bi = GETBINTERNAL(h, idx);
 			pgno = bi->pgno;
 
 			/* Lose the currently pinned page. */
@@ -255,8 +255,8 @@ __bt_stkacq(BTREE *t, PAGE **hp, CURSOR 
 			if ((h = mpool_get(t->bt_mp, pgno, 0)) == NULL)
 				return (1);
 
-			index = NEXTINDEX(h) - 1;
-			BT_PUSH(t, pgno, index);
+			idx = NEXTINDEX(h) - 1;
+			BT_PUSH(t, pgno, idx);
 		}
 		mpool_put(t->bt_mp, h, 0);
 		if ((h = mpool_get(t->bt_mp, prevpg, 0)) == NULL)
@@ -370,7 +370,7 @@ __bt_pdelete(BTREE *t, PAGE *h)
 	BINTERNAL *bi;
 	PAGE *pg;
 	EPGNO *parent;
-	indx_t cnt, index, *ip, offset;
+	indx_t cnt, idx, *ip, offset;
 	u_int32_t nksize;
 	char *from;
 
@@ -391,8 +391,8 @@ __bt_pdelete(BTREE *t, PAGE *h)
 		if ((pg = mpool_get(t->bt_mp, parent->pgno, 0)) == NULL)
 			return (RET_ERROR);
 		
-		index = parent->index;
-		bi = GETBINTERNAL(pg, index);
+		idx = parent->index;
+		bi = GETBINTERNAL(pg, idx);
 
 		/* Free any overflow pages. */
 		if (bi->flags & P_BIGKEY &&
@@ -424,11 +424,11 @@ __bt_pdelete(BTREE *t, PAGE *h)
 			pg->upper += nksize;
 
 			/* Adjust indices' offsets, shift the indices down. */
-			offset = pg->linp[index];
-			for (cnt = index, ip = &pg->linp[0]; cnt--; ++ip)
+			offset = pg->linp[idx];
+			for (cnt = idx, ip = &pg->linp[0]; cnt--; ++ip)
 				if (ip[0] < offset)
 					ip[0] += nksize;
-			for (cnt = NEXTINDEX(pg) - index; --cnt; ++ip)
+			for (cnt = NEXTINDEX(pg) - idx; --cnt; ++ip)
 				ip[0] = ip[1] < offset ? ip[1] + nksize : ip[1];
 			pg->lower -= sizeof(indx_t);
 		}
@@ -453,17 +453,13 @@ __bt_pdelete(BTREE *t, PAGE *h)
  *	t:	tree
  *    key:	referenced key
  *	h:	page
  *	index:	index on page to delete
  *
  * Returns:
  *	RET_SUCCESS, RET_ERROR.
  */
 int
-__bt_dleaf(t, key, h, index)
-	BTREE *t;
-	const DBT *key;
-	PAGE *h;
-	u_int index;
+__bt_dleaf(BTREE *t, const DBT *key, PAGE *h, u_int idx)
 {
 	BLEAF *bl;
 	indx_t cnt, *ip, offset;
@@ -474,12 +470,12 @@ __bt_dleaf(t, key, h, index)
 	/* If this record is referenced by the cursor, delete the cursor. */
 	if (F_ISSET(&t->bt_cursor, CURS_INIT) &&
 	    !F_ISSET(&t->bt_cursor, CURS_ACQUIRE) &&
-	    t->bt_cursor.pg.pgno == h->pgno && t->bt_cursor.pg.index == index &&
-	    __bt_curdel(t, key, h, index))
+	    t->bt_cursor.pg.pgno == h->pgno && t->bt_cursor.pg.index == idx &&
+	    __bt_curdel(t, key, h, idx))
 		return (RET_ERROR);
 
 	/* If the entry uses overflow pages, make them available for reuse. */
-	to = bl = GETBLEAF(h, index);
+	to = bl = GETBLEAF(h, idx);
 	if (bl->flags & P_BIGKEY && __ovfl_delete(t, bl->bytes) == RET_ERROR)
 		return (RET_ERROR);
 	if (bl->flags & P_BIGDATA &&
@@ -493,18 +489,18 @@ __bt_dleaf(t, key, h, index)
 	h->upper += nbytes;
 
 	/* Adjust the indices' offsets, shift the indices down. */
-	offset = h->linp[index];
-	for (cnt = index, ip = &h->linp[0]; cnt--; ++ip)
+	offset = h->linp[idx];
+	for (cnt = idx, ip = &h->linp[0]; cnt--; ++ip)
 		if (ip[0] < offset)
 			ip[0] += nbytes;
-	for (cnt = NEXTINDEX(h) - index; --cnt; ++ip)
+	for (cnt = NEXTINDEX(h) - idx; --cnt; ++ip)
 		ip[0] = ip[1] < offset ? ip[1] + nbytes : ip[1];
 	h->lower -= sizeof(indx_t);
 
 	/* If the cursor is on this page, adjust it as necessary. */
 	if (F_ISSET(&t->bt_cursor, CURS_INIT) &&
 	    !F_ISSET(&t->bt_cursor, CURS_ACQUIRE) &&
-	    t->bt_cursor.pg.pgno == h->pgno && t->bt_cursor.pg.index > index)
+	    t->bt_cursor.pg.pgno == h->pgno && t->bt_cursor.pg.index > idx)
 		--t->bt_cursor.pg.index;
 
 	return (RET_SUCCESS);
@@ -518,17 +514,13 @@ __bt_dleaf(t, key, h, index)
  *	t:	tree
  *    key:	referenced key (or NULL)
  *	h:	page
  *  index:	index on page to delete
  *
  * Returns:
  *	RET_SUCCESS, RET_ERROR.
  */
 static int
-__bt_curdel(t, key, h, index)
-	BTREE *t;
-	const DBT *key;
-	PAGE *h;
-	u_int index;
+__bt_curdel(BTREE *t, const DBT *key, PAGE *h, u_int idx)
 {
 	CURSOR *c;
 	EPG e;
@@ -551,7 +543,7 @@ __bt_curdel(t, key, h, index)
 		 */
 		if (key == NULL) {
 			e.page = h;
-			e.index = index;
+			e.index = idx;
 			if ((status = __bt_ret(t, &e,
 			    &c->key, &c->key, NULL, NULL, 1)) != RET_SUCCESS)
 				return (status);
@@ -559,25 +551,25 @@ __bt_curdel(t, key, h, index)
 			key = &c->key;
 		}
 		/* Check previous key, if not at the beginning of the page. */
-		if (index > 0) { 
+		if (idx > 0) { 
 			e.page = h;
-			e.index = index - 1;
+			e.index = idx - 1;
 			if (__bt_cmp(t, key, &e) == 0) {
 				F_SET(c, CURS_BEFORE);
 				goto dup2;
 			}
 		}
 		/* Check next key, if not at the end of the page. */
-		if (index < NEXTINDEX(h) - 1) {
+		if (idx < NEXTINDEX(h) - 1) {
 			e.page = h;
-			e.index = index + 1;
+			e.index = idx + 1;
 			if (__bt_cmp(t, key, &e) == 0) {
 				F_SET(c, CURS_AFTER);
 				goto dup2;
 			}
 		}
 		/* Check previous key if at the beginning of the page. */
-		if (index == 0 && h->prevpg != P_INVALID) {
+		if (idx == 0 && h->prevpg != P_INVALID) {
 			if ((pg = mpool_get(t->bt_mp, h->prevpg, 0)) == NULL)
 				return (RET_ERROR);
 			e.page = pg;
@@ -589,7 +581,7 @@ __bt_curdel(t, key, h, index)
 			mpool_put(t->bt_mp, pg, 0);
 		}
 		/* Check next key if at the end of the page. */
-		if (index == NEXTINDEX(h) - 1 && h->nextpg != P_INVALID) {
+		if (idx == NEXTINDEX(h) - 1 && h->nextpg != P_INVALID) {
 			if ((pg = mpool_get(t->bt_mp, h->nextpg, 0)) == NULL)
 				return (RET_ERROR);
 			e.page = pg;
@@ -605,7 +597,7 @@ dup2:				c->pg.pgno = e.page->pgno;
 		}
 	}
 	e.page = h;
-	e.index = index;
+	e.index = idx;
 	if (curcopy || (status =
 	    __bt_ret(t, &e, &c->key, &c->key, NULL, NULL, 1)) == RET_SUCCESS) {
 		F_SET(c, CURS_ACQUIRE);
@@ -453,17 +453,13 @@ __bt_pdelete(BTREE *t, PAGE *h)
  *    key:	referenced key
  *	h:	page
- *	index:	index on page to delete
+ *	idx:	index on page to delete
  *
  * Returns:
@@ -518,17 +514,13 @@ __bt_dleaf(t, key, h, index)
  *    key:	referenced key (or NULL)
  *	h:	page
- *  index:	index on page to delete
+ *    idx:	index on page to delete
  *
  * Returns:

Modified: head/lib/libc/db/btree/bt_put.c
==============================================================================
--- head/lib/libc/db/btree/bt_seq.c	Mon Mar  2 23:47:18 2009	(r189291)
+++ head/lib/libc/db/btree/bt_seq.c	Tue Mar  3 02:16:12 2009	(r189292)
@@ -232,7 +232,7 @@ __bt_seqadv(BTREE *t, EPG *ep, int flags
 {
 	CURSOR *c;
 	PAGE *h;
-	indx_t index;
+	indx_t idx;
 	pgno_t pg;
 	int exact;
 
@@ -270,15 +270,15 @@ __bt_seqadv(BTREE *t, EPG *ep, int flags
 		 */
 		if (F_ISSET(c, CURS_AFTER))
 			goto usecurrent;
-		index = c->pg.index;
-		if (++index == NEXTINDEX(h)) {
+		idx = c->pg.index;
+		if (++idx == NEXTINDEX(h)) {
 			pg = h->nextpg;
 			mpool_put(t->bt_mp, h, 0);
 			if (pg == P_INVALID)
 				return (RET_SPECIAL);
 			if ((h = mpool_get(t->bt_mp, pg, 0)) == NULL)
 				return (RET_ERROR);
-			index = 0;
+			idx = 0;
 		}
 		break;
 	case R_PREV:			/* Previous record. */
@@ -293,22 +293,22 @@ usecurrent:		F_CLR(c, CURS_AFTER | CURS_
 			ep->index = c->pg.index;
 			return (RET_SUCCESS);
 		}
-		index = c->pg.index;
-		if (index == 0) {
+		idx = c->pg.index;
+		if (idx == 0) {
 			pg = h->prevpg;
 			mpool_put(t->bt_mp, h, 0);
 			if (pg == P_INVALID)
 				return (RET_SPECIAL);
 			if ((h = mpool_get(t->bt_mp, pg, 0)) == NULL)
 				return (RET_ERROR);
-			index = NEXTINDEX(h) - 1;
+			idx = NEXTINDEX(h) - 1;
 		} else
-			--index;
+			--idx;
 		break;
 	}
 
 	ep->page = h;
-	ep->index = index;
+	ep->index = idx;
 	return (RET_SUCCESS);
 }
 
@@ -421,13 +421,10 @@ __bt_first(BTREE *t, const DBT *key, EPG
  * Parameters:
  *	t:	the tree
  *   pgno:	page number
  *  index:	page index
  */
 void
-__bt_setcur(t, pgno, index)
-	BTREE *t;
-	pgno_t pgno;
-	u_int index;
+__bt_setcur(BTREE *t, pgno_t pgno, u_int idx)
 {
 	/* Lose any already deleted key. */
 	if (t->bt_cursor.key.data != NULL) {
@@ -439,6 +436,6 @@ __bt_setcur(t, pgno, index)
 
 	/* Update the cursor. */
 	t->bt_cursor.pg.pgno = pgno;
-	t->bt_cursor.pg.index = index;
+	t->bt_cursor.pg.index = idx;
 	F_SET(&t->bt_cursor, CURS_INIT);
 }
@@ -421,13 +421,10 @@ __bt_first(BTREE *t, const DBT *key, EPG
  *	t:	the tree
  *   pgno:	page number
- *  index:	page index
+ *    idx:	page index
  */
 void

Modified: head/lib/libc/db/recno/rec_delete.c
==============================================================================
--- head/lib/libc/db/recno/rec_delete.c	Mon Mar  2 23:47:18 2009	(r189291)
+++ head/lib/libc/db/recno/rec_delete.c	Tue Mar  3 02:16:12 2009	(r189292)
@@ -138,16 +138,13 @@ rec_rdelete(BTREE *t, recno_t nrec)
  *
  * Parameters:
  *	t:	tree
  *	index:	index on current page to delete
  *
  * Returns:
  *	RET_SUCCESS, RET_ERROR.
  */
 int
-__rec_dleaf(t, h, index)
-	BTREE *t;
-	PAGE *h;
-	u_int32_t index;
+__rec_dleaf(BTREE *t, PAGE *h, u_int32_t idx)
 {
 	RLEAF *rl;
 	indx_t *ip, cnt, offset;
@@ -165,7 +162,7 @@ __rec_dleaf(t, h, index)
 	 * down, overwriting the deleted record and its index.  If the record
 	 * uses overflow pages, make them available for reuse.
 	 */
-	to = rl = GETRLEAF(h, index);
+	to = rl = GETRLEAF(h, idx);
 	if (rl->flags & P_BIGDATA && __ovfl_delete(t, rl->bytes) == RET_ERROR)
 		return (RET_ERROR);
 	nbytes = NRLEAF(rl);
@@ -178,8 +175,8 @@ __rec_dleaf(t, h, index)
 	memmove(from + nbytes, from, (char *)to - from);
 	h->upper += nbytes;
 
-	offset = h->linp[index];
-	for (cnt = &h->linp[index] - (ip = &h->linp[0]); cnt--; ++ip)
+	offset = h->linp[idx];
+	for (cnt = &h->linp[idx] - (ip = &h->linp[0]); cnt--; ++ip)
 		if (ip[0] < offset)
 			ip[0] += nbytes;
 	for (cnt = &h->linp[NEXTINDEX(h)] - ip; --cnt; ++ip)
@@ -138,16 +138,13 @@ rec_rdelete(BTREE *t, recno_t nrec)
  * Parameters:
  *	t:	tree
- *	index:	index on current page to delete
+ *	idx:	index on current page to delete
  *
  * Returns:

Modified: head/lib/libc/db/recno/rec_put.c
==============================================================================